@@ -19,7 +19,7 @@ Usage::
     list_domains_paginator: ListDomainsPaginator = client.get_paginator("list_domains")
     select_paginator: SelectPaginator = client.get_paginator("select")
 """
-from mypy_boto3_sdb.client import SimpleDBClient, SimpleDBClient as Client
+from mypy_boto3_sdb.client import SimpleDBClient as Client, SimpleDBClient
 from mypy_boto3_sdb.paginator import ListDomainsPaginator, SelectPaginator
 
 
